@@ -9,8 +9,11 @@ type HmacSha1 = Hmac<Sha1>;
 type HmacSha256 = Hmac<Sha256>;
 type HmacSha512 = Hmac<Sha512>;
 
-pub mod hotp;
-pub mod totp;
+mod hotp;
+mod totp;
+
+pub use totp::Totp;
+pub use hotp::Hotp;
 
 /// GenerationError enumerates all possible errors returned by this library.
 #[derive(Error, Debug)]
@@ -149,9 +152,7 @@ pub fn get_otp_auth_url() {}
 /// 4.  Same as (2.) but taking the bits from (offset + 3)
 /// 5.  OR'ing each of these u32 so that we collapse all of the set bits into one u32
 #[doc(hidden)]
-fn generate(
-    key: String,
-    counter: u128,
+fn generate_otp(
     digits: u32,
     digest_hash: Vec<u8>,
 ) -> std::result::Result<String, GenerationError> {
@@ -184,6 +185,7 @@ fn generate(
     let code = no_offset | one_offset | two_offset | three_offset;
 
     if code == 0 {
+        // This is very unlikely to happen, but as a precaution we will return an Err
         Err(GenerationError::FailedToGenerateOTP())
     } else {
         let padded_string = format!("{:0>width$}", code.to_string(), width = digits as usize);
@@ -197,7 +199,6 @@ fn generate(
 #[doc(hidden)]
 fn verify_delta(
     token: String,
-    key: String,
     counter: u128,
     digits: u32,
     window: u64,
@@ -207,8 +208,8 @@ fn verify_delta(
         return Ok(false);
     }
 
-    for i in counter..=counter + window as u128 {
-        let test_otp = generate(key.clone(), counter, digits, digest_hash.clone())?;
+    for _ in counter..=counter + window as u128 {
+        let test_otp = generate_otp(digits, digest_hash.clone())?;
         if test_otp == token {
             return Ok(true);
         }
@@ -258,7 +259,7 @@ fn generate_secret_ascii(length: u32, symbols: bool) -> String {
 }
 
 #[doc(hidden)]
-fn encodeURIComponent(string: String) -> String {
+fn encode_uri_component(string: String) -> String {
     byte_serialize(string.as_bytes()).collect()
 }
 
@@ -283,8 +284,7 @@ mod digest_tests {
 #[cfg(test)]
 mod generate_secret_tests {
     use crate::{
-        generate_secret, generate_secret_ascii, generate_secret_without_symbols,
-        generate_sized_secret, SYMBOL_SET,
+        generate_secret_ascii, generate_secret_without_symbols, generate_sized_secret, SYMBOL_SET,
     };
 
     #[test]
